appium.common package — Python client 1.0 1.0 documentation

# appium.common package

## Submodules

## appium.common.exceptions module

exception NoSuchContextException(msg: Optional[str] = None, screen: Optional[str] = None, stacktrace: Optional[Sequence[str]] = None)

  Bases: `selenium.common.exceptions.InvalidSwitchToTargetException`

  Thrown when context target to be switched doesn’t exist.

  To find the current set of active contexts, you can get a list of the active contexts in the following way:

  > print(driver.contexts)

## appium.common.helper module

extract_const_attributes(cls: type) → Dict[str, Any]

  Return dict with constants attributes and values in the class(e.g. {‘VAL1’: 1, ‘VAL2’: 2})

  Parameters

    cls – Class to be extracted constants

  Returns

    dict with constants attributes and values in the class

library_version() → str

  Return a version of this python library

## appium.common.logger module

setup_logger(level: int = 0) → None

## Module contents

Appium Python Client: Common classes